==> azure-servicebus-0.50.2.zip: azure-servicebus-0.50.2/azure/servicebus/__init__.py <==
# ------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# -------------------------------------------------------------------------

__version__ = '0.50.2'


from azure.servicebus.common.message import Message, BatchMessage, PeekMessage, DeferredMessage
from azure.servicebus.servicebus_client import ServiceBusClient, QueueClient, TopicClient, SubscriptionClient
from azure.servicebus.common.constants import ReceiveSettleMode, NEXT_AVAILABLE
from azure.servicebus.common.utils import AutoLockRenew
from azure.servicebus.common.errors import (
    ServiceBusError,
    ServiceBusResourceNotFound,
    ServiceBusConnectionError,
    ServiceBusAuthorizationError,
    InvalidHandlerState,
    NoActiveSession,
    MessageAlreadySettled,
    MessageSettleFailed,
    MessageSendFailed,
    MessageLockExpired,
    SessionLockExpired,
    AutoLockRenewFailed,
    AutoLockRenewTimeout)


__all__ = [
    'Message',
    'BatchMessage',
    'PeekMessage',
    'AutoLockRenew',
    'DeferredMessage',
    'ServiceBusClient',
    'QueueClient',
    'TopicClient',
    'SubscriptionClient',
    'ReceiveSettleMode',
    'NEXT_AVAILABLE',
    'ServiceBusError',
    'ServiceBusResourceNotFound',
    'ServiceBusConnectionError',
    'ServiceBusAuthorizationError',
    'InvalidHandlerState',
    'NoActiveSession',
    'MessageAlreadySettled',
    'MessageSettleFailed',
    'MessageSendFailed',
    'MessageLockExpired',
    'SessionLockExpired',
    'AutoLockRenewFailed',
    'AutoLockRenewTimeout']

==> azure-servicebus-0.50.3.zip: azure-servicebus-0.50.3/azure/servicebus/__init__.py <==
# ------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# -------------------------------------------------------------------------

from ._version import VERSION
__version__ = VERSION


from azure.servicebus.common.message import Message, BatchMessage, PeekMessage, DeferredMessage
from azure.servicebus.servicebus_client import ServiceBusClient, QueueClient, TopicClient, SubscriptionClient
from azure.servicebus.common.constants import ReceiveSettleMode, NEXT_AVAILABLE
from azure.servicebus.common.utils import AutoLockRenew
from azure.servicebus.common.errors import (
    ServiceBusError,
    ServiceBusResourceNotFound,
    ServiceBusConnectionError,
    ServiceBusAuthorizationError,
    InvalidHandlerState,
    NoActiveSession,
    MessageAlreadySettled,
    MessageSettleFailed,
    MessageSendFailed,
    MessageLockExpired,
    SessionLockExpired,
    AutoLockRenewFailed,
    AutoLockRenewTimeout)

from uamqp.constants import TransportType


__all__ = [
    'Message',
    'BatchMessage',
    'PeekMessage',
    'AutoLockRenew',
    'DeferredMessage',
    'ServiceBusClient',
    'QueueClient',
    'TopicClient',
    'SubscriptionClient',
    'ReceiveSettleMode',
    'NEXT_AVAILABLE',
    'ServiceBusError',
    'ServiceBusResourceNotFound',
    'ServiceBusConnectionError',
    'ServiceBusAuthorizationError',
    'InvalidHandlerState',
    'NoActiveSession',
    'MessageAlreadySettled',
    'MessageSettleFailed',
    'MessageSendFailed',
    'MessageLockExpired',
    'SessionLockExpired',
    'AutoLockRenewFailed',
    'AutoLockRenewTimeout',
    'TransportType']
